@@ -6,6 +6,9 @@ backend = conf.get_matplotlib_backend()
 if not backend in "default":
     matplotlib.use(backend)
 
+if conf.instance.general.get("hpc", "hpc_mode", bool):
+    matplotlib.use("Agg")
+
 import matplotlib.pyplot as plt
 import matplotlib.colors as colors
 import matplotlib.cm as cm
