@@ -4,7 +4,7 @@ import numpy as np
 import pytest
 
 import autoarray as aa
-from autoarray import conf
+from autoconf import conf
 from autoarray.fit import fit
 
 directory = path.dirname(path.realpath(__file__))
@@ -22,7 +22,7 @@ def set_config_path():
 
 @pytest.fixture(name="mask_7x7")
 def make_mask_7x7():
-    mask_2d = np.array(
+    mask = np.array(
         [
             [True, True, True, True, True, True, True],
             [True, True, True, True, True, True, True],
@@ -34,12 +34,12 @@ def make_mask_7x7():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=mask_2d, pixel_scales=(1.0, 1.0), sub_size=1)
+    return aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0), sub_size=1)
 
 
 @pytest.fixture(name="sub_mask_7x7")
 def make_sub_mask_7x7():
-    mask_2d = np.array(
+    mask = np.array(
         [
             [True, True, True, True, True, True, True],
             [True, True, True, True, True, True, True],
@@ -51,12 +51,12 @@ def make_sub_mask_7x7():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=mask_2d, sub_size=2, pixel_scales=(1.0, 1.0))
+    return aa.Mask.manual(mask=mask, sub_size=2, pixel_scales=(1.0, 1.0))
 
 
 @pytest.fixture(name="mask_7x7_1_pix")
 def make_mask_7x7_1_pix():
-    mask_2d = np.array(
+    mask = np.array(
         [
             [True, True, True, True, True, True, True],
             [True, True, True, True, True, True, True],
@@ -68,12 +68,12 @@ def make_mask_7x7_1_pix():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=mask_2d, pixel_scales=(1.0, 1.0))
+    return aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
 
 @pytest.fixture(name="blurring_mask_7x7")
 def make_blurring_mask_7x7():
-    blurring_mask_2d = np.array(
+    blurring_mask = np.array(
         [
             [True, True, True, True, True, True, True],
             [True, False, False, False, False, False, True],
@@ -85,12 +85,12 @@ def make_blurring_mask_7x7():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=blurring_mask_2d, pixel_scales=(1.0, 1.0))
+    return aa.Mask.manual(mask=blurring_mask, pixel_scales=(1.0, 1.0))
 
 
 @pytest.fixture(name="mask_6x6")
 def make_mask_6x6():
-    mask_2d = np.array(
+    mask = np.array(
         [
             [True, True, True, True, True, True],
             [True, True, True, True, True, True],
@@ -101,7 +101,7 @@ def make_mask_6x6():
         ]
     )
 
-    return aa.Mask.manual(mask_2d=mask_2d, pixel_scales=(1.0, 1.0))
+    return aa.Mask.manual(mask=mask, pixel_scales=(1.0, 1.0))
 
 
 # GRIDS #
@@ -109,12 +109,19 @@ def make_mask_6x6():
 
 @pytest.fixture(name="grid_7x7")
 def make_grid_7x7(mask_7x7):
-    return aa.MaskedGrid.from_mask(mask=mask_7x7)
+    return aa.Grid.from_mask(mask=mask_7x7)
 
 
 @pytest.fixture(name="sub_grid_7x7")
 def make_sub_grid_7x7(sub_mask_7x7):
-    return aa.MaskedGrid.from_mask(mask=sub_mask_7x7)
+    return aa.Grid.from_mask(mask=sub_mask_7x7)
+
+
+@pytest.fixture(name="grid_iterate_7x7")
+def make_grid_iterate_7x7(mask_7x7):
+    return aa.GridIterate.from_mask(
+        mask=mask_7x7, fractional_accuracy=0.9999, sub_steps=[2, 4, 8, 16]
+    )
 
 
 @pytest.fixture(name="sub_grid_7x7_simple")
@@ -128,7 +135,7 @@ def make_sub_grid_7x7_simple(mask_7x7, sub_grid_7x7):
 
 @pytest.fixture(name="blurring_grid_7x7")
 def make_blurring_grid_7x7(blurring_mask_7x7):
-    return aa.MaskedGrid.from_mask(mask=blurring_mask_7x7)
+    return aa.Grid.from_mask(mask=blurring_mask_7x7)
 
 
 # CONVOLVERS #
@@ -156,7 +163,7 @@ def make_noise_map_7x7():
 
 @pytest.fixture(name="positions_7x7")
 def make_positions_7x7():
-    return aa.Coordinates(coordinates=[[(0.1, 0.1), (0.2, 0.2)], [(0.3, 0.3)]])
+    return aa.GridCoordinates(coordinates=[[(0.1, 0.1), (0.2, 0.2)], [(0.3, 0.3)]])
 
 
 @pytest.fixture(name="imaging_7x7")
@@ -301,7 +308,7 @@ def make_voronoi_pixelization_grid_9(grid_7x7):
         pixel_scales=1.0,
     )
     return aa.GridVoronoi(
-        grid_1d=grid_9,
+        grid=grid_9,
         nearest_pixelization_1d_index_for_mask_1d_index=np.zeros(
             shape=grid_7x7.shape_1d, dtype="int"
         ),
